<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
  <context>
    <name>ConfigDialog</name>
    <message>
      <location filename="../config.py" line="86" />
      <source>Using configuration file at:</source>
      <translation>Використовуються налаштування з файлу:</translation>
    </message>
    <message>
      <location filename="../config.py" line="105" />
      <source>Behavior</source>
      <translation>Поведінка</translation>
    </message>
    <message>
      <location filename="../config.py" line="106" />
      <source>Automatically save documents</source>
      <translation>Автоматично зберігати документи</translation>
    </message>
    <message>
      <location filename="../config.py" line="107" />
      <source>Automatically open last documents on startup</source>
      <translation>Автоматично відкривати останні документи при запуску</translation>
    </message>
    <message>
      <location filename="../config.py" line="108" />
      <source>Number of recent documents</source>
      <translation>Кількість недавніх документів</translation>
    </message>
    <message>
      <location filename="../config.py" line="109" />
      <source>Restore window geometry</source>
      <translation>Відновлювати геометрію вікна</translation>
    </message>
    <message>
      <location filename="../config.py" line="110" />
      <source>Default preview state</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../config.py" line="111" />
      <source>Open external links in ReText window</source>
      <translation>Відкриті зовнішні посилання у вікні ReText</translation>
    </message>
    <message>
      <location filename="../config.py" line="112" />
      <source>Markdown syntax extensions (comma-separated)</source>
      <translation>Розширення синтаксису Markdown (розділені комами)</translation>
    </message>
    <message>
      <location filename="../config.py" line="114" />
      <source>Enable synchronized scrolling for Markdown</source>
      <translation>Увімкнути синхронне гортання для Markdown</translation>
    </message>
    <message>
      <location filename="../config.py" line="179" />
      <location filename="../config.py" line="118" />
      <source>Editor</source>
      <translation>Редагувати</translation>
    </message>
    <message>
      <location filename="../config.py" line="119" />
      <source>Highlight current line</source>
      <translation>Виділяти поточний рядок</translation>
    </message>
    <message>
      <location filename="../config.py" line="120" />
      <source>Show line numbers</source>
      <translation>Показувати номери рядків</translation>
    </message>
    <message>
      <location filename="../config.py" line="121" />
      <source>Line numbers are relative to current line</source>
      <translation>Починати нумерацію рядків з поточного</translation>
    </message>
    <message>
      <location filename="../config.py" line="122" />
      <source>Tab key inserts spaces</source>
      <translation>Клавіша Tab вставляє пробіли</translation>
    </message>
    <message>
      <location filename="../config.py" line="123" />
      <source>Tabulation width</source>
      <translation>Ширина табулювання</translation>
    </message>
    <message>
      <location filename="../config.py" line="124" />
      <source>Draw vertical line at column</source>
      <translation>Малювати вертикальну лінію у стовпчику</translation>
    </message>
    <message>
      <location filename="../config.py" line="125" />
      <source>Enable soft wrap</source>
      <translation>Переносити текст</translation>
    </message>
    <message>
      <location filename="../config.py" line="126" />
      <source>Show document stats</source>
      <translation>Показувати статистику документа</translation>
    </message>
    <message>
      <location filename="../config.py" line="127" />
      <source>Ordered list mode</source>
      <translation>Режим впорядкованого списку</translation>
    </message>
    <message>
      <location filename="../config.py" line="129" />
      <source>Interface</source>
      <translation>Інтерфейс</translation>
    </message>
    <message>
      <location filename="../config.py" line="130" />
      <source>Hide toolbar</source>
      <translation>Приховати панель інструментів</translation>
    </message>
    <message>
      <location filename="../config.py" line="131" />
      <source>Icon theme name</source>
      <translation>Встановити тему піктограм</translation>
    </message>
    <message>
      <location filename="../config.py" line="132" />
      <source>Stylesheet file</source>
      <translation>Файл стилю Qt</translation>
    </message>
    <message>
      <location filename="../config.py" line="133" />
      <source>Hide tabs bar when there is only one tab</source>
      <translation>Приховати панель вкладок, коли лише одна вкладка</translation>
    </message>
    <message>
      <location filename="../config.py" line="134" />
      <source>Show full path in window title</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../config.py" line="135" />
      <source>Show directory tree</source>
      <translation>Показати дерево директорій</translation>
    </message>
    <message>
      <location filename="../config.py" line="136" />
      <source>Working directory</source>
      <translation>Робоча директорія</translation>
    </message>
    <message>
      <location filename="../config.py" line="161" />
      <source>Help</source>
      <translation>Довідка</translation>
    </message>
    <message>
      <location filename="../config.py" line="180" />
      <source>Live preview</source>
      <translation>Одночасний перегляд</translation>
    </message>
    <message>
      <location filename="../config.py" line="181" />
      <source>Normal preview</source>
      <translation>Звичайний перегляд</translation>
    </message>
    <message>
      <location filename="../config.py" line="186" />
      <source>Disabled</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../config.py" line="187" />
      <source>Cursor Line</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../config.py" line="188" />
      <source>Wrapped Line</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../config.py" line="193" />
      <source>Increment</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../config.py" line="194" />
      <source>Repeat</source>
      <translation>Повторити</translation>
    </message>
  </context>
  <context>
    <name>DirectorySelectButton</name>
    <message>
      <location filename="../config.py" line="61" />
      <source>Select directory to open</source>
      <translation type="unfinished" />
    </message>
  </context>
  <context>
    <name>EncodingDialog</name>
    <message>
      <location filename="../dialogs.py" line="63" />
      <source>Enter encoding name:</source>
      <translation type="unfinished" />
    </message>
  </context>
  <context>
    <name>FileDialogButton</name>
    <message>
      <location filename="../config.py" line="35" />
      <source>(none)</source>
      <translation>(не обраний)</translation>
    </message>
  </context>
  <context>
    <name>FileSelectButton</name>
    <message>
      <location filename="../config.py" line="53" />
      <source>Select file to open</source>
      <translation>Виберіть файл для відкриття</translation>
    </message>
  </context>
  <context>
    <name>InsertTableDialog</name>
    <message>
      <location filename="../tabledialog.py" line="27" />
      <source>Insert table</source>
      <translation>Вставити таблицю</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="36" />
      <source>Number of rows</source>
      <translation>Кількість рядків</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="37" />
      <source>Number of columns</source>
      <translation>Кількість стовпців</translation>
    </message>
  </context>
  <context>
    <name>LocaleDialog</name>
    <message>
      <location filename="../dialogs.py" line="43" />
      <source>Enter locale name (example: en_US)</source>
      <translation>Введіть код мови (наприклад: uk_UA)</translation>
    </message>
    <message>
      <location filename="../dialogs.py" line="44" />
      <source>It is possible to specify multiple languages, separated by comma.</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../dialogs.py" line="50" />
      <source>Set as default</source>
      <translation>Типово</translation>
    </message>
  </context>
  <context>
    <name>Proxy</name>
    <message>
      <location filename="../fakevimeditor.py" line="62" />
      <source>No write since last change (add ! to override)</source>
      <translation>Є незбережені зміни (додайте ! для нехтування)</translation>
    </message>
    <message>
      <location filename="../fakevimeditor.py" line="118" />
      <source>Information</source>
      <translation>Інформація</translation>
    </message>
  </context>
  <context>
    <name>ReTextEdit</name>
    <message>
      <location filename="../editor.py" line="252" />
      <source>Add to dictionary</source>
      <translation>Додати до словника</translation>
    </message>
    <message>
      <location filename="../editor.py" line="464" />
      <source>Save image</source>
      <translation>Зберегти зображення</translation>
    </message>
    <message>
      <location filename="../editor.py" line="466" />
      <source>Images (*.png *.jpg)</source>
      <translation>Зображення (*.png *.jpg)</translation>
    </message>
  </context>
  <context>
    <name>ReTextTab</name>
    <message>
      <location filename="../tab.py" line="174" />
      <source>New document</source>
      <translation>Новий документ</translation>
    </message>
    <message>
      <location filename="../tab.py" line="179" />
      <source>Could not parse file contents, check if you have the &lt;a href="%s"&gt;necessary module&lt;/a&gt; installed!</source>
      <translation>Не вдалося опрацювати вміст файлу, переконайтеся, що встановлено &lt;a href="%s"&gt;необхідний модуль&lt;/a&gt;!</translation>
    </message>
    <message>
      <location filename="../tab.py" line="487" />
      <source>Create missing file?</source>
      <translation>Створити пропущений файл?</translation>
    </message>
    <message>
      <location filename="../tab.py" line="488" />
      <source>The file '%s' does not exist.

Do you want to create it?</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../tab.py" line="520" />
      <source>File could not be created</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../tab.py" line="521" />
      <source>Could not create file '%s': %s</source>
      <translation type="unfinished" />
    </message>
  </context>
  <context>
    <name>ReTextWindow</name>
    <message>
      <location filename="../window.py" line="91" />
      <source>File toolbar</source>
      <translation>Панель файлу</translation>
    </message>
    <message>
      <location filename="../window.py" line="93" />
      <source>Edit toolbar</source>
      <translation>Панель редагування</translation>
    </message>
    <message>
      <location filename="../window.py" line="95" />
      <source>Search toolbar</source>
      <translation>Панель пошуку</translation>
    </message>
    <message>
      <location filename="../window.py" line="99" />
      <source>New</source>
      <translation>Новий</translation>
    </message>
    <message>
      <location filename="../window.py" line="101" />
      <source>Open</source>
      <translation>Відкрити</translation>
    </message>
    <message>
      <location filename="../window.py" line="103" />
      <source>Set encoding</source>
      <translation>Встановити кодування</translation>
    </message>
    <message>
      <location filename="../window.py" line="1187" />
      <location filename="../window.py" line="106" />
      <source>Reload</source>
      <translation>Перезавантажити</translation>
    </message>
    <message>
      <location filename="../window.py" line="109" />
      <source>Save</source>
      <translation>Зберегти</translation>
    </message>
    <message>
      <location filename="../window.py" line="112" />
      <source>Save as</source>
      <translation>Зберегти як</translation>
    </message>
    <message>
      <location filename="../window.py" line="114" />
      <source>Next tab</source>
      <translation>Наступна вкладка</translation>
    </message>
    <message>
      <location filename="../window.py" line="116" />
      <source>Previous tab</source>
      <translation>Попередня вкладка</translation>
    </message>
    <message>
      <location filename="../window.py" line="118" />
      <source>Close tab</source>
      <translation>Закрити вкладку</translation>
    </message>
    <message>
      <location filename="../window.py" line="120" />
      <source>Print</source>
      <translation>Друкувати</translation>
    </message>
    <message>
      <location filename="../window.py" line="122" />
      <source>Print preview</source>
      <translation>Попередній перегляд перед друком</translation>
    </message>
    <message>
      <location filename="../window.py" line="124" />
      <source>View HTML code</source>
      <translation>Переглянути код HTML</translation>
    </message>
    <message>
      <location filename="../window.py" line="125" />
      <source>Change editor font</source>
      <translation>Змінити шрифт редактора</translation>
    </message>
    <message>
      <location filename="../window.py" line="127" />
      <source>Change preview font</source>
      <translation>Змінити шрифт перегляду</translation>
    </message>
    <message>
      <location filename="../window.py" line="129" />
      <source>Find text</source>
      <translation>Знайти текст</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <location filename="../window.py" line="131" />
      <source>Go to line</source>
      <translation>Перейти до рядка</translation>
    </message>
    <message>
      <location filename="../window.py" line="134" />
      <source>Preview</source>
      <translation>Перегляд</translation>
    </message>
    <message>
      <location filename="../window.py" line="144" />
      <source>Live preview</source>
      <translation>Одночасний перегляд</translation>
    </message>
    <message>
      <location filename="../window.py" line="148" />
      <source>Insert table</source>
      <translation>Вставити таблицю</translation>
    </message>
    <message>
      <location filename="../window.py" line="150" />
      <source>Table editing mode</source>
      <translation>Режим редагування таблиць</translation>
    </message>
    <message>
      <location filename="../window.py" line="153" />
      <source>Insert images by file path</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../window.py" line="156" />
      <source>FakeVim mode</source>
      <translation>Режим FakeVim</translation>
    </message>
    <message>
      <location filename="../window.py" line="161" />
      <source>Fullscreen mode</source>
      <translation>На увесь екран</translation>
    </message>
    <message>
      <location filename="../window.py" line="649" />
      <location filename="../window.py" line="164" />
      <source>Preferences</source>
      <translation>Налаштування</translation>
    </message>
    <message>
      <location filename="../window.py" line="171" />
      <source>Quit</source>
      <translation>Вийти</translation>
    </message>
    <message>
      <location filename="../window.py" line="174" />
      <source>Undo</source>
      <translation>Скасувати дію</translation>
    </message>
    <message>
      <location filename="../window.py" line="176" />
      <source>Redo</source>
      <translation>Повторити дію</translation>
    </message>
    <message>
      <location filename="../window.py" line="178" />
      <source>Copy</source>
      <translation>Скопіювати</translation>
    </message>
    <message>
      <location filename="../window.py" line="180" />
      <source>Cut</source>
      <translation>Вирізати</translation>
    </message>
    <message>
      <location filename="../window.py" line="182" />
      <source>Paste</source>
      <translation>Вставити</translation>
    </message>
    <message>
      <location filename="../window.py" line="184" />
      <source>Paste image</source>
      <translation>Вставити зображення</translation>
    </message>
    <message>
      <location filename="../window.py" line="186" />
      <source>Move line up</source>
      <translation>Посунути рядок вгору</translation>
    </message>
    <message>
      <location filename="../window.py" line="188" />
      <source>Move line down</source>
      <translation>Посунути рядок вниз</translation>
    </message>
    <message>
      <location filename="../window.py" line="196" />
      <source>Enable</source>
      <translation>Увімкнути</translation>
    </message>
    <message>
      <location filename="../window.py" line="197" />
      <source>Set locale</source>
      <translation>Вибрати мову</translation>
    </message>
    <message>
      <location filename="../window.py" line="198" />
      <source>Use WebEngine (Chromium) renderer</source>
      <translation>Використовувати WebEngine (Chromium)</translation>
    </message>
    <message>
      <location filename="../window.py" line="204" />
      <source>Show directory</source>
      <translation>Переглянути теку</translation>
    </message>
    <message>
      <location filename="../window.py" line="205" />
      <source>Next</source>
      <translation>Наступне</translation>
    </message>
    <message>
      <location filename="../window.py" line="207" />
      <source>Previous</source>
      <translation>Попереднє</translation>
    </message>
    <message>
      <location filename="../window.py" line="209" />
      <source>Replace</source>
      <translation>Замінити</translation>
    </message>
    <message>
      <location filename="../window.py" line="211" />
      <source>Replace all</source>
      <translation>Замінити все</translation>
    </message>
    <message>
      <location filename="../window.py" line="214" />
      <source>Close</source>
      <translation>Закрити</translation>
    </message>
    <message>
      <location filename="../window.py" line="218" />
      <source>Get help online</source>
      <translation>Отримати довідку в мережі</translation>
    </message>
    <message>
      <location filename="../window.py" line="219" />
      <source>What's new</source>
      <translation>Що нового</translation>
    </message>
    <message>
      <location filename="../window.py" line="220" />
      <source>About ReText</source>
      <translation>Про ReText</translation>
    </message>
    <message>
      <location filename="../window.py" line="223" />
      <source>About Qt</source>
      <translation>Про Qt</translation>
    </message>
    <message>
      <location filename="../window.py" line="238" />
      <source>Bold</source>
      <translation>Жирний</translation>
    </message>
    <message>
      <location filename="../window.py" line="240" />
      <source>Italic</source>
      <translation>Курсив</translation>
    </message>
    <message>
      <location filename="../window.py" line="242" />
      <source>Underline</source>
      <translation>Підкреслення</translation>
    </message>
    <message>
      <location filename="../window.py" line="315" />
      <location filename="../window.py" line="251" />
      <source>Formatting</source>
      <translation>Форматування</translation>
    </message>
    <message>
      <location filename="../window.py" line="255" />
      <source>Symbols</source>
      <translation>Символи</translation>
    </message>
    <message>
      <location filename="../window.py" line="260" />
      <source>&amp;File</source>
      <translation>&amp;Файл</translation>
    </message>
    <message>
      <location filename="../window.py" line="261" />
      <source>&amp;Edit</source>
      <translation>&amp;Редагування</translation>
    </message>
    <message>
      <location filename="../window.py" line="262" />
      <source>&amp;Help</source>
      <translation>&amp;Довідка</translation>
    </message>
    <message>
      <location filename="../window.py" line="265" />
      <source>Open recent</source>
      <translation>Відкрити останній</translation>
    </message>
    <message>
      <location filename="../window.py" line="278" />
      <source>Export</source>
      <translation>Експорт</translation>
    </message>
    <message>
      <location filename="../window.py" line="303" />
      <source>Spell check</source>
      <translation>Перевірка правопису</translation>
    </message>
    <message>
      <location filename="../window.py" line="312" />
      <source>Default markup</source>
      <translation>Типова розмітка</translation>
    </message>
    <message>
      <location filename="../window.py" line="360" />
      <source>Search</source>
      <translation>Пошук</translation>
    </message>
    <message>
      <location filename="../window.py" line="363" />
      <source>Replace with</source>
      <translation>Замінити на</translation>
    </message>
    <message>
      <location filename="../window.py" line="365" />
      <source>Case sensitively</source>
      <translation>Врахувати регістр</translation>
    </message>
    <message>
      <location filename="../window.py" line="552" />
      <location filename="../window.py" line="506" />
      <source>New document</source>
      <translation>Новий документ</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <source>Type the line number</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../window.py" line="737" />
      <source>Please, save the file somewhere.</source>
      <translation>Будь ласка, збережіть кудись файл.</translation>
    </message>
    <message>
      <location filename="../window.py" line="856" />
      <source>Select one or several files to open</source>
      <translation>Виберіть один або кілька файлів</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>Supported files</source>
      <translation>Файли що підтримуються</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>All files (*)</source>
      <translation>Всі файли (*)</translation>
    </message>
    <message>
      <location filename="../window.py" line="912" />
      <source>Plain text (*.txt)</source>
      <translation>Простий текст (*.txt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="915" />
      <source>%s files</source>
      <comment>Example of final string: Markdown files</comment>
      <translation>Файли %s</translation>
    </message>
    <message>
      <location filename="../window.py" line="984" />
      <location filename="../window.py" line="928" />
      <source>Save file</source>
      <translation>Зберегти файл</translation>
    </message>
    <message>
      <location filename="../window.py" line="936" />
      <source>Cannot save to file which is open in another tab!</source>
      <translation>Неможливо зберегти файл відкритий в іншій вкладці!</translation>
    </message>
    <message>
      <location filename="../window.py" line="974" />
      <source>Export document to ODT</source>
      <translation>Експортувати як ODT</translation>
    </message>
    <message>
      <location filename="../window.py" line="975" />
      <source>OpenDocument text files (*.odt)</source>
      <translation>Текстові файли OpenDocument (*.odt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="985" />
      <source>HTML files (*.html *.htm)</source>
      <translation>Файли HTML (*.html *.htm)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1005" />
      <source>Unrecognized paperSize setting "%s".</source>
      <translation>Нерозпізнаний розмір паперу "%s".</translation>
    </message>
    <message>
      <location filename="../window.py" line="1020" />
      <source>Export document to PDF</source>
      <translation>Експортувати як PDF</translation>
    </message>
    <message>
      <location filename="../window.py" line="1022" />
      <source>PDF files (*.pdf)</source>
      <translation>Файли PDF (*.pdf)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1046" />
      <source>Print document</source>
      <translation>Друкувати документ</translation>
    </message>
    <message>
      <location filename="../window.py" line="1070" />
      <source>Export document</source>
      <translation>Експортувати документ</translation>
    </message>
    <message>
      <location filename="../window.py" line="1090" />
      <source>Failed to execute the command:</source>
      <translation>Помилка при виконанні команди:</translation>
    </message>
    <message>
      <location filename="../window.py" line="1126" />
      <source>Alt text</source>
      <translation>Альтернативний текст</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <location filename="../window.py" line="1126" />
      <source>URL</source>
      <translation>URL</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <source>Link text</source>
      <translation>Текст посилання</translation>
    </message>
    <message>
      <location filename="../window.py" line="1168" />
      <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
      <translation>Цей файл був видалений іншим додатком.
Будь ласка, переконайтеся перед виходом, що ви зберегли файл.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1177" />
      <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
      <translation>Цей документ був змінений іншим застосунком.
Бажаєте перезавантажити файл і втратити незбережені зміни?
</translation>
    </message>
    <message>
      <location filename="../window.py" line="1182" />
      <source>Automatic saving has been temporarily disabled for this tab to prevent data loss. It will be re-enabled when you reload the file or save it manually.</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../window.py" line="1205" />
      <source>The document has been modified.
Do you want to save your changes?</source>
      <translation>Документ було змінено.
Бажаєте зберегти ці зміни?</translation>
    </message>
    <message>
      <location filename="../window.py" line="1232" />
      <source>HTML code</source>
      <translation>Код HTML</translation>
    </message>
    <message>
      <location filename="../window.py" line="1243" />
      <source>Select one or several images to open</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../window.py" line="1264" />
      <source>ReText %s (using PyMarkups %s)</source>
      <translation>ReText %s (використовує PyMarkups %s)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1265" />
      <source>Simple but powerful editor for Markdown and reStructuredText</source>
      <translation>Простий але потужний текстовий редактор для Markdown та reStructuredText
</translation>
    </message>
    <message>
      <location filename="../window.py" line="1267" />
      <source>Author: Dmitry Shachnev, 2011</source>
      <translation>Автор: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
      <location filename="../window.py" line="1270" />
      <source>Markdown syntax</source>
      <translation>Синтаксис Markdown</translation>
    </message>
    <message>
      <location filename="../window.py" line="1272" />
      <source>reStructuredText syntax</source>
      <translation>Синтаксис reStructuredText</translation>
    </message>
  </context>
  <context>
    <name>TextInfoArea</name>
    <message>
      <location filename="../editor.py" line="659" />
      <source>%d w | %d a | %d c</source>
      <comment>count of words, alphanumeric characters, all characters</comment>
      <translation>%d слів | %d цифробуквенних символів | %d символів</translation>
    </message>
  </context>
  <context>
    <name>main</name>
    <message>
      <location filename="../__main__.py" line="84" />
      <source>Open the files in preview mode</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../__main__.py" line="86" />
      <source>Create a new window even if there is an existing one</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../__main__.py" line="90" />
      <source>List of files to open</source>
      <translation type="unfinished" />
    </message>
  </context>
</TS>
